@@ -12,6 +12,8 @@ import platform
 
 
 DEBUG = bool(os.environ.get("SETUPTOOLS_SCM_DEBUG"))
+IS_WINDOWS = platform.system() == 'Windows'
+PY2 = sys.version_info < (3,)
 
 
 def trace(*k):
@@ -32,9 +34,7 @@ def _always_strings(env_dict):
     On Windows and Python 2, environment dictionaries must be strings
     and not unicode.
     """
-    is_windows = platform.system == 'Windows'
-    PY2 = sys.version_info < (3,)
-    if is_windows or PY2:
+    if IS_WINDOWS or PY2:
         env_dict.update(
             (key, str(value))
             for (key, value) in env_dict.items()
